@@ -1,5 +1,5 @@
 import pydantic
-from . import Price
+from .PriceModel import Price
 
 
 class Refund(pydantic.BaseModel):
