@@ -1,6 +1,6 @@
 from __future__ import annotations
 from pydantic import BaseModel
-from . import Price
+from .PriceModel import Price
 
 class ShippingProfileDestination(BaseModel):
     shipping_profile_destination_id: int
