@@ -74,7 +74,7 @@ class EtsySession:
             headers = {"x-api-key": self.CLIENT_KEY}
 
         url = f"{self.__base_endpoint}{endpoint}"
-        req: requests.Response = self.__oauth2_session.request(
+        req = self.__oauth2_session.request(
             method, url, headers=headers, *args, **kwargs)
 
         return self.create_response(req)
